#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.smt_interfaces.dmo_offsets import DMOOffsets
from pycatia.smt_interfaces.dmo_thicknesses import DMOThicknesses
from pycatia.smt_interfaces.free_spaces import FreeSpaces
from pycatia.smt_interfaces.part_comps import PartComps
from pycatia.smt_interfaces.silhouettes import Silhouettes
from pycatia.smt_interfaces.swept_volumes import SweptVolumes
from pycatia.smt_interfaces.wrappings import Wrappings


class OptimizerWorkBench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         OptimizerWorkBench
                | 
                | Interface to access a CATIAOptimizerWorkBench
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.optimizer_work_bench = com_object

    @property
    def free_spaces(self) -> FreeSpaces:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FreeSpaces() As FreeSpaces (Read Only)
                | 
                |     Returns FreeSpaces.

        :rtype: FreeSpaces
        """

        return FreeSpaces(self.optimizer_work_bench.FreeSpaces)

    @property
    def offsets(self) -> DMOOffsets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Offsets() As DMOOffsets (Read Only)
                | 
                |     Returns Offsets.

        :rtype: DMOOffsets
        """

        return DMOOffsets(self.optimizer_work_bench.Offsets)

    @property
    def part_comps(self) -> PartComps:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartComps() As PartComps (Read Only)
                | 
                |     Returns PartComps.

        :rtype: PartComps
        """

        return PartComps(self.optimizer_work_bench.PartComps)

    @property
    def silhouettes(self) -> Silhouettes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Silhouettes() As Silhouettes (Read Only)
                | 
                |     Returns or sets the constraint driving mode. For constraint types
                |     supporting the concept of value, such as distance constraints, the driving mode
                |     tells whether the constraint value actually drives the geometry position, or,
                |     conversely, is driven by it.
                | 
                |     Example:
                |         The following example retrieves in currentSilhouettes the driving mode
                |         for the distCst distance constraint:
                | 
                |          currentSilhouettes = distCst.Silhouettes

        :rtype: Silhouettes
        """

        return Silhouettes(self.optimizer_work_bench.Silhouettes)

    @property
    def swept_volumes(self) -> SweptVolumes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SweptVolumes() As SweptVolumes (Read Only)
                | 
                |     Returns SweptVolumes.

        :rtype: SweptVolumes
        """

        return SweptVolumes(self.optimizer_work_bench.SweptVolumes)

    @property
    def thicknesses(self) -> DMOThicknesses:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Thicknesses() As DMOThicknesses (Read Only)
                | 
                |     Returns Thicknesses.

        :rtype: DMOThicknesses
        """

        return DMOThicknesses(self.optimizer_work_bench.Thicknesses)

    @property
    def wrappings(self) -> Wrappings:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Wrappings() As Wrappings (Read Only)
                | 
                |     Returns Wrappings.

        :rtype: Wrappings
        """

        return Wrappings(self.optimizer_work_bench.Wrappings)

    def check(self, i_context: str, i_instance_id: str, i_latest_shape: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Check(CATBSTR iContext,
                | CATBSTR iInstanceID,
                | CATBSTR iLatestShape) As long
                | 
                |     Check 1 component

        :param str i_context:
        :param str i_instance_id:
        :param str i_latest_shape:
        :rtype: int
        """
        return self.optimizer_work_bench.Check(i_context, i_instance_id, i_latest_shape)

    def query_neighbours(
            self,
            i_accuracy: float,
            i_clearance: float,
            i_reference_selection: tuple,
            i_type_query: int
    ) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func QueryNeighbours(double iAccuracy,
                | double iClearance,
                | CATSafeArrayVariant iReferenceSelection,
                | long iTypeQuery) As long
                | 
                |     Compute the Neighbours

        :param float i_accuracy:
        :param float i_clearance:
        :param tuple i_reference_selection:
        :param int i_type_query:
        :rtype: int
        """
        return self.optimizer_work_bench.QueryNeighbours(i_accuracy, i_clearance, i_reference_selection, i_type_query)

    def __repr__(self):
        return f'OptimizerWorkBench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class AnalysisColorMap(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisColorMap
                | 
                | Represents the Color Map Object of the post-processing Image
                | Object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_color_map = com_object

    @property
    def discrete_mode(self) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DiscreteMode() As CATVariant
                | 
                |     Gets the Discrete mode for the Color Map
                | 
                |     Parameters:
                | 
                |         oDiscreteMode
                |             Output Boolean for the Discrete Mode True : indicates that Discrete mode is enabled for the color map. False: indicates that Discrete mode is disabled for the color map. This Method Returns E_FAIL if the Parent Image is not uptodate. 
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oDiscreteMode = analysisColorMap.DiscreteMode
                |          In this example, oDiscreteMode is the output Discrete Mode for
                |          analysisColorMap.

        :rtype: cat_variant
        """

        return self.analysis_color_map.DiscreteMode

    @discrete_mode.setter
    def discrete_mode(self, value: cat_variant):
        """
        :param cat_variant value:
        """

        self.analysis_color_map.DiscreteMode = value

    @property
    def distribution_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DistributionMode() As SPMDistributionMode
                | 
                |     Gets the Distribution Mode for the Color Map
                | 
                |     Parameters:
                | 
                |         oDistMode
                |             Returns the Distribution Mode (ColorMap type) SPM_LINEAR : For Linear Distribution Mode SPM_HISTOGRAM : For Histogram Distribution Mode SPM_LOG : For Logarithmic Distribution Mode This Method Returns E_FAIL if the Parent Image is not uptodate. 
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oDistMode = analysisColorMap.DistributionMode
                |          In this example, oDistMode is the output distribution mode for
                |          analysisColorMap.

        :return: enum spm_distribution_mode
        :rtype: int
        """

        return self.analysis_color_map.DistributionMode

    @distribution_mode.setter
    def distribution_mode(self, value: int):
        """
        :param int value: enum spm_distribution_mode
        """

        self.analysis_color_map.DistributionMode = value

    @property
    def imposed_max_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImposedMaxValue() As double
                | 
                |     Gets the Imposed Maximum value for the Color Map
                | 
                |     Parameters:
                | 
                |         oMaxValue
                |             Returns Imposed Maximum value Returned value will be in CATIA
                |             Units. This Method Returns E_FAIL if the Parent Image is not uptodate.
                |             
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oMaxValue = analysisColorMap.ImposedMaxValue
                |          In this example, oMaxValue is the output Imposed Maximum value for
                |          analysisColorMap.

        :rtype: float
        """

        return self.analysis_color_map.ImposedMaxValue

    @imposed_max_value.setter
    def imposed_max_value(self, value: float):
        """
        :param float value:
        """

        self.analysis_color_map.ImposedMaxValue = value

    @property
    def imposed_min_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImposedMinValue() As double
                | 
                |     Gets the Imposed Minimum value for the Color Map
                | 
                |     Parameters:
                | 
                |         oMinValue
                |             Returns imposed minimum value Returned value will be in CATIA
                |             Units. This Method Returns E_FAIL if the Parent Image is not uptodate.
                |
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oMinValue = analysisColorMap.ImposedMinValue
                |          In this example, oMinValue is the output Imposed Minimum value for
                |          analysisColorMap.

        :rtype: float
        """

        return self.analysis_color_map.ImposedMinValue

    @imposed_min_value.setter
    def imposed_min_value(self, value: float):
        """
        :param float value:
        """

        self.analysis_color_map.ImposedMinValue = value

    @property
    def inverse_mode(self) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InverseMode() As CATVariant
                | 
                |     Gets the Inverse mode for the Color Map
                | 
                |     Parameters:
                | 
                |         oInverseMode
                |             Output Boolean for the Inverse Mode True : indicates that Inverse mode is enabled for the color map. False: indicates that Inverse mode is disabled for the color map. This Method Returns E_FAIL if the Parent Image is not uptodate. 
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oInverseMode = analysisColorMap.InverseMode
                |          In this example, oInverseMode is the output Inverse Mode for
                |          analysisColorMap.

        :rtype: cat_variant
        """

        return self.analysis_color_map.InverseMode

    @inverse_mode.setter
    def inverse_mode(self, value: cat_variant):
        """
        :param cat_variant value:
        """

        self.analysis_color_map.InverseMode = value

    @property
    def nb_colors(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbColors() As long
                | 
                |     Gets the Number of colors for the Color Map
                | 
                |     Parameters:
                | 
                |         oNbColors
                |             returns number of colors as output from the color map. This Method
                |             Returns E_FAIL if the Parent Image is not uptodate.
                |             
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oNbColors = analysisColorMap.NbColors
                |          In this example, oNbColors is the output Number of colors for
                |          analysisColorMap.

        :rtype: int
        """

        return self.analysis_color_map.NbColors

    @nb_colors.setter
    def nb_colors(self, value: int):
        """
        :param int value:
        """

        self.analysis_color_map.NbColors = value

    @property
    def smooth_mode(self) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SmoothMode() As CATVariant
                | 
                |     Gets the Smooth mode for the Color Map
                | 
                |     Parameters:
                | 
                |         oSmoothMode
                |             Output Boolean for the Smooth Mode True : indicates that Smooth mode is enabled for the color map. False: indicates that Smooth mode is disabled for the color map. This Method Returns E_FAIL if the Parent Image is not uptodate. 
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object oSmoothMode = analysisColorMap.SmoothMode
                |          In this example, oSmoothMode is the output Smooth Mode for
                |          analysisColorMap.

        :rtype: cat_variant
        """

        return self.analysis_color_map.SmoothMode

    @smooth_mode.setter
    def smooth_mode(self, value: cat_variant):
        """
        :param cat_variant value:
        """

        self.analysis_color_map.SmoothMode = value

    def get_distribution_value(self, index_value: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDistributionValue(long indexValue) As double
                | 
                |     Gets the Value for the Distribution of Color Map
                | 
                |     Parameters:
                | 
                |         indexValue
                |             The index whose Value we get. This integer should be greater than 0
                |             and less than NbColors. Else Method Fails. 
                |         oModeValue
                |             Returns the value @param indexValue Returned value will be in CATIA
                |             Units. This Method Returns E_FAIL if the Parent Image is not uptodate.
                |             
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object Set oModeValue = analysisColorMap.GetDistributionValue (3)
                |          In this example, oModeValue is the output value of the Distribution
                |          list at Index 3.

        :param int index_value:
        :rtype: float
        """
        return self.analysis_color_map.GetDistributionValue(index_value)

    def set_distribution_value(self, index_value: int, i_mode_value: float, i_smoothening_flag: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDistributionValue(long indexValue,
                | double iModeValue,
                | CATVariant iSmootheningFlag)
                | 
                |     Sets the Value for the Distribution of Color Map
                | 
                |     Parameters:
                | 
                |         indexValue
                |             The index whose Value will be set. This integer should be greater
                |             than 0 and less than NbColors. Else Method Fails. 
                |         iModeValue
                |             The Value to be set. This value should be in between
                |             Computed/Imposed Min/Max values. Else Method Fails. In addition if @param
                |             iSmootheningFlag is False, this value should be in between the immediate lower
                |             and upper values. Else Method Fails. Value has to be provided in CATIA Units.
                |             
                |         iSmootheningFlag
                |             if True: Does either upper or lower smoothening of values. if
                |             False: Does not smoothen values. But sets only the given index value. This
                |             Method Returns E_FAIL if Color Map is Discrete. 
                | 
                |     Example:
                | 
                |          : analysisColorMap is the ColorMap Object  Example 1:
                | 
                |          Call analysisColorMap.SetDistributionValue(3, 3e+09,
                |          True)
                | 
                |          This sets the value 3e+09 at 3rd Index of the list. It will smoothen
                |          the distribution values
                |          for the color-map object analysisColorMap.
                |          Should be in between Computed/Imposed Min/Max values.
                |          
                |          Example 2:
                | 
                |          Call analysisColorMap.SetDistributionValue(3, 10e+09,
                |          False)
                | 
                |          This sets the value 10e+09 at 3rd Index of the list. It will not
                |          smoothen the distribution
                |          for the color-map object analysisColorMap.
                |          10e+09 should be greater than Index 2 value and lesser than Index 4
                |          value.
                |          Should be in between Computed/Imposed Min/Max values.

        :param int index_value:
        :param float i_mode_value:
        :param cat_variant i_smoothening_flag:
        :rtype: None
        """
        return self.analysis_color_map.SetDistributionValue(index_value, i_mode_value, i_smoothening_flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_distribution_value'
        # # vba_code = """
        # # Public Function set_distribution_value(analysis_color_map)
        # #     Dim indexValue (2)
        # #     analysis_color_map.SetDistributionValue indexValue
        # #     set_distribution_value = indexValue
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     Updates the visualization of the color map. This method should be called
                |     after one or all previous PUT methods are called on Color Map.

        :rtype: None
        """
        return self.analysis_color_map.Update()

    def __repr__(self):
        return f'AnalysisColorMap(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve_2D import Curve2D
from pycatia.sketcher_interfaces.point_2D import Point2D
from pycatia.system_interfaces.system_service import SystemService


class Ellipse2D(Curve2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Ellipse2D
                | 
                | Class defining an ellipse in 2D Space.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ellipse_2d = com_object

    @property
    def center_point(self) -> Point2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterPoint() As Point2D
                | 
                |     Returns the center point of the ellipse.
                | 
                |     Parameters:
                | 
                |         iCenterPoint
                |             The center point of the ellipse

        :rtype: Point2D
        """

        return Point2D(self.ellipse_2d.CenterPoint)

    @center_point.setter
    def center_point(self, value: Point2D):
        """
        :param Point2D value:
        """

        self.ellipse_2d.CenterPoint = value

    @property
    def major_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MajorRadius() As double (Read Only)
                | 
                |     Returns the radius of the ellipse major axis
                | 
                |     Parameters:
                | 
                |         oMajorRadius
                |             The radius of the major axis

        :rtype: float
        """

        return self.ellipse_2d.MajorRadius

    @property
    def minor_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MinorRadius() As double (Read Only)
                | 
                |     Returns the radius of the ellipse minor axis
                | 
                |     Parameters:
                | 
                |         oMinorRadius
                |             The radius of the minor axis

        :rtype: float
        """

        return self.ellipse_2d.MinorRadius

    def get_center(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCenter(CATSafeArrayVariant oCenter)
                | 
                |     Returns the center of the ellipse in 2D space
                | 
                |     Parameters:
                | 
                |         oCenter[0]
                |             The X Coordinate of the center point of the ellipse
                |             
                |         oCenter[1]
                |             The Y Coordinate of the center point of the
                |             ellipse

        :rtype: tuple
        """

        vba_function_name = 'get_center'
        vba_code = """
        Public Function get_center(ellipse2_d)
            Dim oCenter (1)
            ellipse2_d.GetCenter oCenter
            get_center = oCenter
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_major_axis(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMajorAxis(CATSafeArrayVariant oMajorAxis)
                | 
                |     Returns the unit vector of the major axis of the ellipse in 2D
                |     space
                | 
                |     Parameters:
                | 
                |         oMajorAxis[0]
                |             The length of the major axis 
                |         oMajorAxis[1]
                |             The length of the major axis

        :rtype: tuple
        """

        vba_function_name = 'get_major_axis'
        vba_code = """
        Public Function get_major_axis(ellipse2_d)
            Dim oMajorAxis (1)
            ellipse2_d.GetMajorAxis oMajorAxis
            get_major_axis = oMajorAxis
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_minor_axis(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMinorAxis(CATSafeArrayVariant oMajorAxis)
                | 
                |     Returns the unit vector of the minor axis of the ellipse in 2D
                |     space
                | 
                |     Parameters:
                | 
                |         oMinorAxis[0]
                |             The length of the major axis 
                |         oMinorAxis[1]
                |             The length of the major axis

        :rtype: tuple
        """

        vba_function_name = 'get_minor_axis'
        vba_code = """
        Public Function get_minor_axis(ellipse2_d)
            Dim oMajorAxis (1)
            ellipse2_d.GetMinorAxis oMajorAxis
            get_minor_axis = oMajorAxis
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_data(self,
                 i_center_x: float,
                 i_center_y: float,
                 i_major_x: float,
                 i_major_y: float,
                 i_major_radius: float,
                 i_minor_radius: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetData(double iCenterX,
                | double iCenterY,
                | double iMajorX,
                | double iMajorY,
                | double iMajorRadius,
                | double iMinorRadius)
                | 
                |     Modifies the caracteristics of the ellipse
                | 
                |     Parameters:
                | 
                |         iCenterX
                |             The X Coordinate of the ellipse center 
                |         iCenterY
                |             The Y Coordinate of the ellipse center 
                |         iMajorX
                |             The X coordinate of the Major axis direction 
                |         iMajorY
                |             The Y coordinate of the Major axis direction 
                |         iMajorRadius
                |             The length of the major axis 
                |         iMinorRadius
                |             The length of the minor axis

        :param float i_center_x:
        :param float i_center_y:
        :param float i_major_x:
        :param float i_major_y:
        :param float i_major_radius:
        :param float i_minor_radius:
        :rtype: None
        """
        return self.ellipse_2d.SetData(i_center_x, i_center_y, i_major_x, i_major_y, i_major_radius, i_minor_radius)

    def __repr__(self):
        return f'Ellipse2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.drafting_interfaces.drawing_view import DrawingView
from pycatia.system_interfaces.any_object import AnyObject


class SchDropOffView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchDropOffView
                | 
                | Manage the drop off views in a schematic viewer.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_drop_off_view = com_object

    def add_drop_off_view(
            self,
            i_view: DrawingView,
            o_view: DrawingView,
            i_db2_pos_xy: tuple,
            i_db1_scale: float,
            i_db1_angl: float
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDropOffView(DrawingView iView,
                | DrawingView oView,
                | CATSafeArrayVariant iDb2PosXY,
                | double iDb1Scale,
                | double iDb1Angl)
                | 
                |     Adds a drafting view to the schematics diagram.
                | 
                |     Parameters:
                | 
                |         iView
                |             pointer to drafting view to add 
                |         oView
                |             pointer to newly added drafting in this document 
                |         iDb2PosXY
                |             pointer to XY coordinate for placement, if NULL, the position is
                |             the same as that of the input view. 
                |         iDb1Scale
                |             scale of view added, if NULL, scale is assumed to be that of the
                |             input view. 
                |         iDb1Angle
                |             The view orientation, if NULL, orientation is assumed to be that of
                |             the input view. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchDropOffView
                |          Dim objArg1 As DrawingView
                |          Dim objArg2 As DrawingView
                |          Dim dbVar3(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.AddDropOffViewobjArg1,objArg2,dbVar3,dbVar3,dbVar3

        :param DrawingView i_view:
        :param DrawingView o_view:
        :param tuple i_db2_pos_xy:
        :param float i_db1_scale:
        :param float i_db1_angl:
        :rtype: tuple
        """
        return self.sch_drop_off_view.AddDropOffView(
            i_view.com_object,
            o_view.com_object,
            i_db2_pos_xy,
            i_db1_scale,
            i_db1_angl
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_drop_off_view'
        # # vba_code = """
        # # Public Function add_drop_off_view(sch_drop_off_view)
        # #     Dim iView (2)
        # #     sch_drop_off_view.AddDropOffView iView
        # #     add_drop_off_view = iView
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_drop_off_views(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListDropOffViews() As SchListOfObjects
                | 
                |     Lists drafting views in this schematics diagram.
                | 
                |     Parameters:
                | 
                |         oLDropOffViews
                |             A list of drafting views 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchDropOffView
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListDropOffViews

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_drop_off_view.ListDropOffViews())

    def remove_drop_off_view(self, i_view_to_remove: DrawingView) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveDropOffView(DrawingView iViewToRemove)
                | 
                |     Removes a drafting view from the schematics diagram.
                | 
                |     Parameters:
                | 
                |         iViewToRemove
                |             pointer to drafting view to remove 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchDropOffView
                |          Dim objArg1 As DrawingView
                |           ...
                |          objThisIntf.RemoveDropOffViewobjArg1

        :param DrawingView i_view_to_remove:
        :rtype: None
        """
        return self.sch_drop_off_view.RemoveDropOffView(i_view_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_drop_off_view'
        # # vba_code = """
        # # Public Function remove_drop_off_view(sch_drop_off_view)
        # #     Dim iViewToRemove (2)
        # #     sch_drop_off_view.RemoveDropOffView iViewToRemove
        # #     remove_drop_off_view = iViewToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchDropOffView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class StepSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         StepSettingAtt
                | 
                | The interface to access a CATIAStepSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.step_setting_att = com_object

    @property
    def att_ap(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttAP() As short
                | 
                |     Returns or sets the AttAP parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttAP

    @att_ap.setter
    def att_ap(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttAP = value

    @property
    def att_asm(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttASM() As short
                | 
                |     Returns or sets the AttASM parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttASM

    @att_asm.setter
    def att_asm(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttASM = value

    @property
    def att_asmgvp(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttASMGVP() As short
                | 
                |     Returns or sets the AttASMGVP parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttASMGVP

    @att_asmgvp.setter
    def att_asmgvp(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttASMGVP = value

    @property
    def att_angle_def_fitting(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttAngleDefFiting() As float
                | 
                |     Returns or sets the AttAngleDefFiting parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttAngleDefFiting

    @att_angle_def_fitting.setter
    def att_angle_def_fitting(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttAngleDefFiting = value

    @property
    def att_annotation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttAnnotation() As short
                | 
                |     Returns or sets the AttAnnotation parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttAnnotation

    @att_annotation.setter
    def att_annotation(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttAnnotation = value

    @property
    def att_composites(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttComposites() As short
                | 
                |     Returns or sets the AttComposites parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttComposites

    @att_composites.setter
    def att_composites(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttComposites = value

    @property
    def att_export_rep_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttExportRepMode() As short
                | 
                |     Returns or sets the AttExportRepMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttExportRepMode

    @att_export_rep_mode.setter
    def att_export_rep_mode(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttExportRepMode = value

    @property
    def att_fitting(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttFitting() As short
                | 
                |     Returns or sets the AttFitting parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttFitting

    @att_fitting.setter
    def att_fitting(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttFitting = value

    @property
    def att_gvp(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVP() As short
                | 
                |     Returns or sets the AttGVP parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttGVP

    @att_gvp.setter
    def att_gvp(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttGVP = value

    @property
    def att_gvpcops(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVPCOPS() As short
                | 
                |     Returns or sets the AttGVPCOPS parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttGVPCOPS

    @att_gvpcops.setter
    def att_gvpcops(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttGVPCOPS = value

    @property
    def att_gvpcopssag(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVPCOPSSAG() As double
                | 
                |     Returns or sets the AttGVPCOPSSAG parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttGVPCOPSSAG

    @att_gvpcopssag.setter
    def att_gvpcopssag(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttGVPCOPSSAG = value

    @property
    def att_gvpcops_tol(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVPCOPSTol() As double
                | 
                |     Returns or sets the AttGVPCOPSSAG parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttGVPCOPSTol

    @att_gvpcops_tol.setter
    def att_gvpcops_tol(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttGVPCOPSTol = value

    @property
    def att_gvpcdg(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVPCdG() As double
                | 
                |     Returns or sets the AttGVPCdG parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttGVPCdG

    @att_gvpcdg.setter
    def att_gvpcdg(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttGVPCdG = value

    @property
    def att_gvpva(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGVPVA() As double
                | 
                |     Returns or sets the AttGVPVA parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttGVPVA

    @att_gvpva.setter
    def att_gvpva(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttGVPVA = value

    @property
    def att_group_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttGroupMode() As short
                | 
                |     Returns or sets the AttGroupMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttGroupMode

    @att_group_mode.setter
    def att_group_mode(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttGroupMode = value

    @property
    def att_header_author(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttHeaderAuthor() As CATBSTR
                | 
                |     Returns or sets the AttHeaderAuthor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.step_setting_att.AttHeaderAuthor

    @att_header_author.setter
    def att_header_author(self, value: str):
        """
        :param str value:
        """

        self.step_setting_att.AttHeaderAuthor = value

    @property
    def att_header_authorisation(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttHeaderAuthorisation() As CATBSTR
                | 
                |     Returns or sets the AttHeaderAuthorisation parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.step_setting_att.AttHeaderAuthorisation

    @att_header_authorisation.setter
    def att_header_authorisation(self, value: str):
        """
        :param str value:
        """

        self.step_setting_att.AttHeaderAuthorisation = value

    @property
    def att_header_description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttHeaderDescription() As CATBSTR
                | 
                |     Returns or sets the AttHeaderDescription parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.step_setting_att.AttHeaderDescription

    @att_header_description.setter
    def att_header_description(self, value: str):
        """
        :param str value:
        """

        self.step_setting_att.AttHeaderDescription = value

    @property
    def att_header_organisation(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttHeaderOrganisation() As CATBSTR
                | 
                |     Returns or sets the AttHeaderOrganisation parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: str
        """

        return self.step_setting_att.AttHeaderOrganisation

    @att_header_organisation.setter
    def att_header_organisation(self, value: str):
        """
        :param str value:
        """

        self.step_setting_att.AttHeaderOrganisation = value

    @property
    def att_iasm(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttIASM() As short
                | 
                |     Returns or sets the AttIASM parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttIASM

    @att_iasm.setter
    def att_iasm(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttIASM = value

    @property
    def att_layers_filters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttLayersFilters() As short
                | 
                |     Returns or sets the AttLayersFilters parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttLayersFilters

    @att_layers_filters.setter
    def att_layers_filters(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttLayersFilters = value

    @property
    def att_multi_cad(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttMultiCAD() As short
                | 
                |     Returns or sets the AttMultiCAD parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttMultiCAD

    @att_multi_cad.setter
    def att_multi_cad(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttMultiCAD = value

    @property
    def att_optimize_c2(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttOptimizeC2() As short
                | 
                |     Returns or sets the AttOptimizeC2 parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttOptimizeC2

    @att_optimize_c2.setter
    def att_optimize_c2(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttOptimizeC2 = value

    @property
    def att_report(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttReport() As short
                | 
                |     Returns or sets the AttReport parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttReport

    @att_report.setter
    def att_report(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttReport = value

    @property
    def att_show(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttShow() As short
                | 
                |     Returns or sets the AttShow parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttShow

    @att_show.setter
    def att_show(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttShow = value

    @property
    def att_tess_preferred(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttTessPrefered() As short
                | 
                |     Returns or sets the AttTessPrefered parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttTessPrefered

    @att_tess_preferred.setter
    def att_tess_preferred(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttTessPrefered = value

    @property
    def att_tol_def_opt_fit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttTolDefOptFit() As float
                | 
                |     Returns or sets the AttTolDefOptFit parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.step_setting_att.AttTolDefOptFit

    @att_tol_def_opt_fit.setter
    def att_tol_def_opt_fit(self, value: float):
        """
        :param float value:
        """

        self.step_setting_att.AttTolDefOptFit = value

    @property
    def att_uda(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttUDA() As short
                | 
                |     Returns or sets the AttUDA parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttUDA

    @att_uda.setter
    def att_uda(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttUDA = value

    @property
    def att_units(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttUnits() As short
                | 
                |     Returns or sets the AttUnits parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.AttUnits

    @att_units.setter
    def att_units(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.AttUnits = value

    @property
    def edge_in_tess_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EdgeInTessMode() As short
                | 
                |     Returns or sets the EdgeTessMode parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.step_setting_att.EdgeInTessMode

    @edge_in_tess_mode.setter
    def edge_in_tess_mode(self, value: int):
        """
        :param int value:
        """

        self.step_setting_att.EdgeInTessMode = value

    def get_att_ap_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttAPInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttAP
                |     parameter.
                |     Role:Retrieves the state of the AttAP parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttAPInfo(io_admin_level, io_locked)

    def get_att_asmgvp_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttASMGVPInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttASMGVP
                |     parameter.
                |     Role:Retrieves the state of the AttASMGVP parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttASMGVPInfo(io_admin_level, io_locked)

    def get_att_asm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttASMInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttASM
                |     parameter.
                |     Role:Retrieves the state of the AttASM parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttASMInfo(io_admin_level, io_locked)

    def get_att_angle_def_fiting_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttAngleDefFitingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttAngleDefFiting
                |     parameter.
                |     Role:Retrieves the state of the AttAngleDefFiting parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttAngleDefFitingInfo(io_admin_level, io_locked)

    def get_att_annotation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttAnnotationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttAnnotation
                |     parameter.
                |     Role:Retrieves the state of the AttAnnotation parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttAnnotationInfo(io_admin_level, io_locked)

    def get_att_composites_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttCompositesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttComposites
                |     parameter.
                |     Role:Retrieves the state of the AttComposites parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttCompositesInfo(io_admin_level, io_locked)

    def get_att_export_rep_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttExportRepModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttExportRepMode
                |     parameter.
                |     Role:Retrieves the state of the AttExportRepMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttExportRepModeInfo(io_admin_level, io_locked)

    def get_att_fitting_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttFittingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttFitting
                |     parameter.
                |     Role:Retrieves the state of the AttFitting parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttFittingInfo(io_admin_level, io_locked)

    def get_att_gvpcops_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPCOPSInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVP
                |     parameter.
                |     Role:Retrieves the state of the AttGVP parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPCOPSInfo(io_admin_level, io_locked)

    def get_att_gvpcopssag_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPCOPSSAGInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVPVA
                |     parameter.
                |     Role:Retrieves the state of the AttGVPVA parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPCOPSSAGInfo(io_admin_level, io_locked)

    def get_att_gvpcops_tol_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPCOPSTolInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVPVA
                |     parameter.
                |     Role:Retrieves the state of the AttGVPVA parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPCOPSTolInfo(io_admin_level, io_locked)

    def get_att_gvpcdg_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPCdGInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVPCdG
                |     parameter.
                |     Role:Retrieves the state of the AttGVPCdG parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPCdGInfo(io_admin_level, io_locked)

    def get_att_gvp_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVP
                |     parameter.
                |     Role:Retrieves the state of the AttGVP parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPInfo(io_admin_level, io_locked)

    def get_att_gvpva_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGVPVAInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGVPVA
                |     parameter.
                |     Role:Retrieves the state of the AttGVPVA parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGVPVAInfo(io_admin_level, io_locked)

    def get_att_group_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttGroupModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttGroupMode
                |     parameter.
                |     Role:Retrieves the state of the AttGroupMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttGroupModeInfo(io_admin_level, io_locked)

    def get_att_header_author_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttHeaderAuthorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttHeaderAuthor
                |     parameter.
                |     Role:Retrieves the state of the AttHeaderAuthor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttHeaderAuthorInfo(io_admin_level, io_locked)

    def get_att_header_authorisation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttHeaderAuthorisationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttHeaderAuthorisation
                |     parameter.
                |     Role:Retrieves the state of the AttHeaderAuthorisation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttHeaderAuthorisationInfo(io_admin_level, io_locked)

    def get_att_header_description_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttHeaderDescriptionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttHeaderDescription
                |     parameter.
                |     Role:Retrieves the state of the AttHeaderDescription parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttHeaderDescriptionInfo(io_admin_level, io_locked)

    def get_att_header_organisation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttHeaderOrganisationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttHeaderOrganisation
                |     parameter.
                |     Role:Retrieves the state of the AttHeaderOrganisation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttHeaderOrganisationInfo(io_admin_level, io_locked)

    def get_att_iasm_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttIASMInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttIASM
                |     parameter.
                |     Role:Retrieves the state of the AttIASM parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttIASMInfo(io_admin_level, io_locked)

    def get_att_layers_filters_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttLayersFiltersInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttLayersFilters
                |     parameter.
                |     Role:Retrieves the state of the AttLayersFilters parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttLayersFiltersInfo(io_admin_level, io_locked)

    def get_att_multi_cad_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttMultiCADInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttMultiCAD
                |     parameter.
                |     Role:Retrieves the state of the AttMultiCAD parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttMultiCADInfo(io_admin_level, io_locked)

    def get_att_optimize_c2_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttOptimizeC2Info(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttOptimizeC2
                |     parameter.
                |     Role:Retrieves the state of the AttOptimizeC2 parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttOptimizeC2Info(io_admin_level, io_locked)

    def get_att_report_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttReportInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttReport
                |     parameter.
                |     Role:Retrieves the state of the AttReport parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttReportInfo(io_admin_level, io_locked)

    def get_att_show_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttShowInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttShow
                |     parameter.
                |     Role:Retrieves the state of the AttShow parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttShowInfo(io_admin_level, io_locked)

    def get_att_tess_preferred_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttTessPreferedInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttTessPrefered
                |     parameter.
                |     Role:Retrieves the state of the AttTessPrefered parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttTessPreferedInfo(io_admin_level, io_locked)

    def get_att_tol_def_opt_fit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttTolDefOptFitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttTolDefOptFit
                |     parameter.
                |     Role:Retrieves the state of the AttTolDefOptFit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttTolDefOptFitInfo(io_admin_level, io_locked)

    def get_att_uda_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttUDAInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttUDA
                |     parameter.
                |     Role:Retrieves the state of the AttUDA parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttUDAInfo(io_admin_level, io_locked)

    def get_att_units_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttUnitsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AttUnits
                |     parameter.
                |     Role:Retrieves the state of the AttUnits parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetAttUnitsInfo(io_admin_level, io_locked)

    def get_edge_in_tess_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEdgeInTessInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the EdgeTessMode
                |     parameter.
                |     Role:Retrieves the state of the EdgeTessMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.step_setting_att.GetEdgeInTessInfo(io_admin_level, io_locked)

    def set_att_ap_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttAPLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttAP parameter.
                |     Role:Locks or unlocks the AttAP parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttAPLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_ap_lock'
        # # vba_code = """
        # # Public Function set_att_ap_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttAPLock iLocked
        # #     set_att_ap_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_asmgvp_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttASMGVPLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttASMGVP parameter.
                |     Role:Locks or unlocks the AttASMGVP parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttASMGVPLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_asmgvp_lock'
        # # vba_code = """
        # # Public Function set_att_asmgvp_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttASMGVPLock iLocked
        # #     set_att_asmgvp_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_asm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttASMLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttASM parameter.
                |     Role:Locks or unlocks the AttASM parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttASMLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_asm_lock'
        # # vba_code = """
        # # Public Function set_att_asm_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttASMLock iLocked
        # #     set_att_asm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_angle_def_fiting_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttAngleDefFitingLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttAngleDefFiting parameter.
                |     Role:Locks or unlocks the AttAngleDefFiting parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttAngleDefFitingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_angle_def_fiting_lock'
        # # vba_code = """
        # # Public Function set_att_angle_def_fiting_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttAngleDefFitingLock iLocked
        # #     set_att_angle_def_fiting_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_annotation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttAnnotationLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttAnnotation parameter.
                |     Role:Locks or unlocks the AttAnnotation parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttAnnotationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_annotation_lock'
        # # vba_code = """
        # # Public Function set_att_annotation_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttAnnotationLock iLocked
        # #     set_att_annotation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_composites_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttCompositesLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttComposites parameter.
                |     Role:Locks or unlocks the AttComposites parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttCompositesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_composites_lock'
        # # vba_code = """
        # # Public Function set_att_composites_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttCompositesLock iLocked
        # #     set_att_composites_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_export_rep_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttExportRepModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttExportRepMode parameter.
                |     Role:Locks or unlocks the AttExportRepMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttExportRepModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_export_rep_mode_lock'
        # # vba_code = """
        # # Public Function set_att_export_rep_mode_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttExportRepModeLock iLocked
        # #     set_att_export_rep_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_fitting_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttFittingLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttFitting parameter.
                |     Role:Locks or unlocks the AttFitting parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttFittingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_fitting_lock'
        # # vba_code = """
        # # Public Function set_att_fitting_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttFittingLock iLocked
        # #     set_att_fitting_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvpcops_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPCOPSLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVP parameter.
                |     Role:Locks or unlocks the AttGVP parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPCOPSLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvpcops_lock'
        # # vba_code = """
        # # Public Function set_att_gvpcops_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPCOPSLock iLocked
        # #     set_att_gvpcops_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvpcopssag_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPCOPSSAGLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVPVA parameter.
                |     Role:Locks or unlocks the AttGVPVA parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPCOPSSAGLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvpcopssag_lock'
        # # vba_code = """
        # # Public Function set_att_gvpcopssag_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPCOPSSAGLock iLocked
        # #     set_att_gvpcopssag_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvpcops_tol_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPCOPSTolLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVPVA parameter.
                |     Role:Locks or unlocks the AttGVPVA parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPCOPSTolLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvpcops_tol_lock'
        # # vba_code = """
        # # Public Function set_att_gvpcops_tol_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPCOPSTolLock iLocked
        # #     set_att_gvpcops_tol_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvpcdg_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPCdGLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVPCdG parameter.
                |     Role:Locks or unlocks the AttGVPCdG parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPCdGLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvp_cd_g_lock'
        # # vba_code = """
        # # Public Function set_att_gvp_cd_g_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPCdGLock iLocked
        # #     set_att_gvp_cd_g_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvp_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVP parameter.
                |     Role:Locks or unlocks the AttGVP parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvp_lock'
        # # vba_code = """
        # # Public Function set_att_gvp_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPLock iLocked
        # #     set_att_gvp_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_gvpva_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGVPVALock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGVPVA parameter.
                |     Role:Locks or unlocks the AttGVPVA parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGVPVALock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_gvpva_lock'
        # # vba_code = """
        # # Public Function set_att_gvpva_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGVPVALock iLocked
        # #     set_att_gvpva_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_group_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttGroupModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttGroupMode parameter.
                |     Role:Locks or unlocks the AttGroupMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttGroupModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_group_mode_lock'
        # # vba_code = """
        # # Public Function set_att_group_mode_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttGroupModeLock iLocked
        # #     set_att_group_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_header_author_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttHeaderAuthorLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttHeaderAuthor parameter.
                |     Role:Locks or unlocks the AttHeaderAuthor parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttHeaderAuthorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_header_author_lock'
        # # vba_code = """
        # # Public Function set_att_header_author_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttHeaderAuthorLock iLocked
        # #     set_att_header_author_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_header_authorisation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttHeaderAuthorisationLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttHeaderAuthorisation parameter.
                |     Role:Locks or unlocks the AttHeaderAuthorisation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttHeaderAuthorisationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_header_authorisation_lock'
        # # vba_code = """
        # # Public Function set_att_header_authorisation_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttHeaderAuthorisationLock iLocked
        # #     set_att_header_authorisation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_header_description_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttHeaderDescriptionLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttHeaderDescription parameter.
                |     Role:Locks or unlocks the AttHeaderDescription parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttHeaderDescriptionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_header_description_lock'
        # # vba_code = """
        # # Public Function set_att_header_description_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttHeaderDescriptionLock iLocked
        # #     set_att_header_description_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_header_organisation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttHeaderOrganisationLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttHeaderOrganisation parameter.
                |     Role:Locks or unlocks the AttHeaderOrganisation parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttHeaderOrganisationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_header_organisation_lock'
        # # vba_code = """
        # # Public Function set_att_header_organisation_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttHeaderOrganisationLock iLocked
        # #     set_att_header_organisation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_iasm_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttIASMLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttIASM parameter.
                |     Role:Locks or unlocks the AttIASM parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttIASMLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_iasm_lock'
        # # vba_code = """
        # # Public Function set_att_iasm_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttIASMLock iLocked
        # #     set_att_iasm_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_layers_filters_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttLayersFiltersLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttLayersFilters parameter.
                |     Role:Locks or unlocks the AttLayersFilters parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttLayersFiltersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_layers_filters_lock'
        # # vba_code = """
        # # Public Function set_att_layers_filters_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttLayersFiltersLock iLocked
        # #     set_att_layers_filters_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_multi_cad_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttMultiCADLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttMultiCAD parameter.
                |     Role:Locks or unlocks the AttMultiCAD parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttMultiCADLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_multi_cad_lock'
        # # vba_code = """
        # # Public Function set_att_multi_cad_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttMultiCADLock iLocked
        # #     set_att_multi_cad_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_optimize_c2_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttOptimizeC2Lock(boolean iLocked)
                | 
                |     Locks or unlocks the AttOptimizeC2 parameter.
                |     Role:Locks or unlocks the AttOptimizeC2 parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttOptimizeC2Lock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_optimize_c2_lock'
        # # vba_code = """
        # # Public Function set_att_optimize_c2_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttOptimizeC2Lock iLocked
        # #     set_att_optimize_c2_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_report_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttReportLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttReport parameter.
                |     Role:Locks or unlocks the AttReport parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttReportLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_report_lock'
        # # vba_code = """
        # # Public Function set_att_report_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttReportLock iLocked
        # #     set_att_report_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_show_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttShowLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttShow parameter.
                |     Role:Locks or unlocks the AttShow parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttShowLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_show_lock'
        # # vba_code = """
        # # Public Function set_att_show_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttShowLock iLocked
        # #     set_att_show_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_tess_preferred_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttTessPreferedLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttTessPrefered parameter.
                |     Role:Locks or unlocks the AttTessPrefered parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttTessPreferedLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_tess_prefered_lock'
        # # vba_code = """
        # # Public Function set_att_tess_prefered_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttTessPreferedLock iLocked
        # #     set_att_tess_prefered_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_tol_def_opt_fit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttTolDefOptFitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttTolDefOptFit parameter.
                |     Role:Locks or unlocks the AttTolDefOptFit parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttTolDefOptFitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_tol_def_opt_fit_lock'
        # # vba_code = """
        # # Public Function set_att_tol_def_opt_fit_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttTolDefOptFitLock iLocked
        # #     set_att_tol_def_opt_fit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_uda_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttUDALock(boolean iLocked)
                | 
                |     Locks or unlocks the AttUDA parameter.
                |     Role:Locks or unlocks the AttUDA parameter if it is possible in the current
                |     administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttUDALock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_uda_lock'
        # # vba_code = """
        # # Public Function set_att_uda_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttUDALock iLocked
        # #     set_att_uda_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_att_units_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttUnitsLock(boolean iLocked)
                | 
                |     Locks or unlocks the AttUnits parameter.
                |     Role:Locks or unlocks the AttUnits parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetAttUnitsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_att_units_lock'
        # # vba_code = """
        # # Public Function set_att_units_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetAttUnitsLock iLocked
        # #     set_att_units_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_edge_in_tess_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetEdgeInTessLock(boolean iLocked)
                | 
                |     Locks or unlocks the EdgeTessMode parameter.
                |     Role:Locks or unlocks the AttGroupMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.step_setting_att.SetEdgeInTessLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_edge_in_tess_lock'
        # # vba_code = """
        # # Public Function set_edge_in_tess_lock(step_setting_att)
        # #     Dim iLocked (2)
        # #     step_setting_att.SetEdgeInTessLock iLocked
        # #     set_edge_in_tess_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StepSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_condition import ABQBoundaryCondition
from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQDisplacementBC(ABQBoundaryCondition):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQBoundaryCondition
                |                         ABQDisplacementBC
                | 
                | Represents an Abaqus displacement boundary condition (ABQDisplacementBC)
                | object.
                | Role: Access an Abaqus displacement boundary condition object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_displacement_bc = com_object

    @property
    def use_local_csys(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UselocalCsys() As boolean
                | 
                |     Sets or returns a boolean indicating whether local coordinate system is
                |     used in Displacement BC
                | 
                |     Returns:
                |         boolean specifying whether local csys is active.

        :rtype: bool
        """

        return self.abq_displacement_bc.UselocalCsys

    @use_local_csys.setter
    def use_local_csys(self, value: bool):
        """
        :param bool value:
        """

        self.abq_displacement_bc.UselocalCsys = value

    @property
    def local_csys(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property localCsys() As AxisSystem
                | 
                |     Sets or returns the local coordinate system of the boundary condition's
                |     degrees of freedom.
                | 
                |     Returns:
                |         The local coordinate system.

        :rtype: AxisSystem
        """

        return AxisSystem(self.abq_displacement_bc.localCsys)

    @local_csys.setter
    def local_csys(self, value: AxisSystem):
        """
        :param AxisSystem value:
        """

        self.abq_displacement_bc.localCsys = value

    @property
    def u1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property u1() As double
                | 
                |     Sets or returns the first translational component.
                | 
                |     Returns:
                |         The first translational component.

        :rtype: float
        """

        return self.abq_displacement_bc.u1

    @u1.setter
    def u1(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.u1 = value

    @property
    def u2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property u2() As double
                | 
                |     Sets or returns the second translational component.
                | 
                |     Returns:
                |         The second translational component.

        :rtype: float
        """

        return self.abq_displacement_bc.u2

    @u2.setter
    def u2(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.u2 = value

    @property
    def u3(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property u3() As double
                | 
                |     Sets or returns the third translational component.
                | 
                |     Returns:
                |         The third translational component.

        :rtype: float
        """

        return self.abq_displacement_bc.u3

    @u3.setter
    def u3(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.u3 = value

    @property
    def ur1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ur1() As double
                | 
                |     Sets or returns the first rotational component.
                | 
                |     Returns:
                |         The second rotational component.

        :rtype: float
        """

        return self.abq_displacement_bc.ur1

    @ur1.setter
    def ur1(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.ur1 = value

    @property
    def ur2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ur2() As double
                | 
                |     Sets or returns the second rotational component.
                | 
                |     Returns:
                |         The second rotational component.

        :rtype: float
        """

        return self.abq_displacement_bc.ur2

    @ur2.setter
    def ur2(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.ur2 = value

    @property
    def ur3(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ur3() As double
                | 
                |     Sets or returns the third rotational component.
                | 
                |     Returns:
                |         The third rotational component.

        :rtype: float
        """

        return self.abq_displacement_bc.ur3

    @ur3.setter
    def ur3(self, value: float):
        """
        :param float value:
        """

        self.abq_displacement_bc.ur3 = value

    def get_dof_activation(self, i_dof: int, o_flag: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDOFActivation(long iDOF,
                | boolean oFlag)
                | 
                |     Gets the activation of a DOF for Displacement BC
                | 
                |     Parameters:
                | 
                |         iDOF
                |             The DOF number from 1 to 6, in order U1 = 1,...., UR3 = 6.
                |         oFlag
                |             DOF activation status true or false.

        :param int i_dof:
        :param bool o_flag:
        :rtype: None
        """
        return self.abq_displacement_bc.GetDOFActivation(i_dof, o_flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_dof_activation'
        # # vba_code = """
        # # Public Function get_dof_activation(abq_displacement_bc)
        # #     Dim iDOF (2)
        # #     abq_displacement_bc.GetDOFActivation iDOF
        # #     get_dof_activation = iDOF
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_local_csys_from_publication(self, o_product: Product, o_pub_axis_system: AxisSystem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocalCsysFromPublication(Product oProduct,
                | AxisSystem oPubAxisSystem)
                | 
                |     Gets the published local coordinate system of the Displacement
                |     BC.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         oPubAxisSystem
                |             The CATIA Axis system.
                | 
                |             Refer: CATIAAxisSystem

        :param Product o_product:
        :param AxisSystem o_pub_axis_system:
        :rtype: None
        """
        return self.abq_displacement_bc.GetLocalCsysFromPublication(o_product.com_object, o_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_local_csys_from_publication'
        # # vba_code = """
        # # Public Function get_local_csys_from_publication(abq_displacement_bc)
        # #     Dim oProduct (2)
        # #     abq_displacement_bc.GetLocalCsysFromPublication oProduct
        # #     get_local_csys_from_publication = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_use_coordinate_system_type(self) -> int:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUseCoordinateSystemType() As ABQLocalCsysType
                |
                |     Get the user coordinate system type.
                |
                |     Parameters:
                |
                |         oCsystemType
                |             e.g. ABQ_CARTESIAN (for Cartesian coordinate system),
                |             ABQ_CYLINDRICAL (for Cylindrical coordinate system), ABQ_SPHERICAL (for
                |             Spherical coordinate system),
    
        :return: enum abq_local_csys_type
        :rtype: int
        """
        return self.abq_displacement_bc.GetUseCoordinateSystemType()

    def set_dof_activation(self, i_dof: int, i_flag: bool) -> None:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDOFActivation(long iDOF,
                | boolean iFlag)
                |
                |     Sets the activation of a DOF for Displacement BC
                |
                |     Parameters:
                |
                |         iDOF
                |             The DOF number from 1 to 6, in order U1 = 1,...., UR3 = 6.
                |         iFlag
                |             DOF activation status true or false.
    
        :param int i_dof:
        :param bool i_flag:
        :rtype: None
        """
        return self.abq_displacement_bc.SetDOFActivation(i_dof, i_flag)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dof_activation'
        # # vba_code = """
        # # Public Function set_dof_activation(abq_displacement_bc)
        # #     Dim iDOF (2)
        # #     abq_displacement_bc.SetDOFActivation iDOF
        # #     set_dof_activation = iDOF
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_local_csys_from_publication(self, i_product: Product, i_pub_axis_system: Publication) -> None:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocalCsysFromPublication(Product iProduct,
                | Publication iPubAxisSystem)
                |
                |     Sets the published local coordinate system of the Displacement
                |     BC.
                |
                |     Returns:
                |         Fails if the publication is not on the axis system.
                |     Parameters:
                |
                |         iProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         iPublication
                |             The CATIA Publication on the axis system.
                |
                |             Refer: CATIAPublication
    
        :param Product i_product:
        :param Publication i_pub_axis_system:
        :rtype: None
        """
        return self.abq_displacement_bc.SetLocalCsysFromPublication(i_product.com_object, i_pub_axis_system.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_local_csys_from_publication'
        # # vba_code = """
        # # Public Function set_local_csys_from_publication(abq_displacement_bc)
        # #     Dim iProduct (2)
        # #     abq_displacement_bc.SetLocalCsysFromPublication iProduct
        # #     set_local_csys_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_use_coordinate_system_type(self, i_csystem_type: int) -> None:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUseCoordinateSystemType(ABQLocalCsysType
                | iCsystemType)
                |
                |     Set the user coordinate system type.
                |
                |     Parameters:
                |
                |         iCsystemType
                |             e.g. ABQ_CARTESIAN (for Cartesian coordinate system),
                |             ABQ_CYLINDRICAL (for Cylindrical coordinate system), ABQ_SPHERICAL (for
                |             Spherical coordinate system),
    
        :param int i_csystem_type: enum abq_local_csys_type
        :rtype: None
        """
        return self.abq_displacement_bc.SetUseCoordinateSystemType(i_csystem_type)

    def __repr__(self):
        return f'ABQDisplacementBC(name="{self.name}")'
